import React, { useState, useEffect } from "react";
import { BrowserRouter as Router, Routes, Route } from "react-router-dom";
import UserList from "./components/UserList";
import UserDetails from "./components/UserDetails";
import EditUser from "./components/EditUser";
import './styles.css';
 
const RouteWithProps = ({ Component, props }) => {
  return <Component {...props} />;
};
 
const App = () => {
  const [users, setUsers] = useState([]);
 
  useEffect(() => {
    const storedUsers = JSON.parse(localStorage.getItem("users")) || [];
    setUsers(storedUsers);
  }, []);
 
  useEffect(() => {
    localStorage.setItem("users", JSON.stringify(users));
  }, [users]);
 
  const sharedProps = { users, setUsers };
 
  return (
    <Router>
      <Routes>
        <Route
          path="/"
          element={<RouteWithProps Component={UserList} props={sharedProps} />}
        />
        <Route
          path="/user/:id"
          element={<RouteWithProps Component={UserDetails} props={sharedProps} />}
        />
        <Route
          path="/edit/:id"
          element={<RouteWithProps Component={EditUser} props={sharedProps} />}
        />
      </Routes>
    </Router>
  );
};
 
export default App;